# ModelZoo

This is the ModelZoo created by the students of IIT Madras.

Models : 

    UNet and UNet++

    PointNet

    StackGAN

    PSPNet 

## Installation

Run the following to install:

**pip install modelzoo**

## Developing Model Zoo

To install modelzoo, along with the tools you need to develop and run tests, run the following in your virtualenv:

**pip install -e .[dev]**